@@ -76,8 +76,10 @@ class CLDevice:
                     "installed. "
                     "Please install an SDK or appropriate driver.".format(
                     "CPU" if cpu else "GPU"))
+            min_mem = MIN_GLOBAL_MEM_SIZE_GB * 1024 ** 3
             mem_sizes = [device.get_info(cl.device_info.GLOBAL_MEM_SIZE) for device in devices]
-            if not any(s >= MIN_GLOBAL_MEM_SIZE_GB * 1024 ** 3 for s in mem_sizes):
+            devices = [device for device, mem_size in zip(devices, mem_sizes) if mem_size >= min_mem]
+            if not devices:
                 raise PeanutError(
                     "Your system does not provide a {} device with enough memory. "
                     "The largest memory found was {:.2f} GB. "
